@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #include "e.h"
 
 static void _e_color_dialog_button1_click(void *data, E_Dialog *edia);
@@ -17,7 +13,7 @@ static void _e_color_dialog_cb_csel_change(void *data, Evas_Object *obj);
  * @param color color to initialize to (or NULL for black).
  * @param alpha_enabled if set, uses alpha and let user edit it.
  */
-E_Color_Dialog  *
+E_Color_Dialog *
 e_color_dialog_new(E_Container *con, const E_Color *color, Eina_Bool alpha_enabled)
 {
    E_Color_Dialog *dia;
@@ -28,7 +24,7 @@ e_color_dialog_new(E_Container *con, const E_Color *color, Eina_Bool alpha_enabl
    if (!dia) return NULL;
    dia->dia = e_dialog_new(con, "E", "_color_dialog");
    e_dialog_title_set(dia->dia, _("Color Selector"));
-   
+
    dia->color = calloc(1, sizeof(E_Color));
    dia->initial = calloc(1, sizeof(E_Color));
 
@@ -43,13 +39,12 @@ e_color_dialog_new(E_Container *con, const E_Color *color, Eina_Bool alpha_enabl
    o = e_widget_csel_add(dia->dia->win->evas, dia->color, alpha_enabled);
    evas_object_show(o);
    e_widget_size_min_get(o, &mw, &mh);
-   e_dialog_content_set(dia->dia, o, 460, 260);
+   e_dialog_content_set(dia->dia, o, mw, mh);
    e_widget_on_change_hook_set(o, _e_color_dialog_cb_csel_change, dia);
 
    /* buttons at the bottom */
-   e_dialog_button_add(dia->dia, _("OK"), NULL, _e_color_dialog_button1_click, dia);
+   e_dialog_button_add(dia->dia, _("Select"), NULL, _e_color_dialog_button1_click, dia);
    e_dialog_button_add(dia->dia, _("Cancel"), NULL, _e_color_dialog_button2_click, dia);
-   e_dialog_resizable_set(dia->dia, 1);
    e_win_centered_set(dia->dia->win, 1);
 
    dia->dia->data = dia;
@@ -93,19 +88,20 @@ e_color_dialog_change_callback_set(E_Color_Dialog *dia, void (*func)(E_Color_Dia
 }
 
 static void
-_e_color_dialog_cb_csel_change(void *data, Evas_Object *obj)
+_e_color_dialog_cb_csel_change(void *data, Evas_Object *obj __UNUSED__)
 {
    E_Color_Dialog *dia;
+
    dia = data;
    if (dia->change_func && dia->color)
      dia->change_func(dia, dia->color, dia->change_data);
 }
 
 static void
-_e_color_dialog_button1_click(void *data, E_Dialog *edia)
+_e_color_dialog_button1_click(void *data, E_Dialog *edia __UNUSED__)
 {
    E_Color_Dialog *dia;
-   
+
    dia = data;
    if (dia->select_func && dia->color)
      dia->select_func(dia, dia->color, dia->select_data);
@@ -113,14 +109,14 @@ _e_color_dialog_button1_click(void *data, E_Dialog *edia)
 }
 
 static void
-_e_color_dialog_button2_click(void *data, E_Dialog *edia)
+_e_color_dialog_button2_click(void *data, E_Dialog *edia __UNUSED__)
 {
    E_Color_Dialog *dia;
 
    dia = data;
    if (dia->cancel_func && dia->initial)
      dia->cancel_func(dia, dia->initial, dia->cancel_data);
-   _e_color_dialog_free(data);     	
+   _e_color_dialog_free(data);
 }
 
 static void
@@ -128,9 +124,9 @@ _e_color_dialog_free(E_Color_Dialog *dia)
 {
    if (dia->dia)
      {
-	e_object_del_attach_func_set(E_OBJECT(dia->dia), NULL);
-	e_object_del(E_OBJECT(dia->dia));
-	dia->dia = NULL;
+        e_object_del_attach_func_set(E_OBJECT(dia->dia), NULL);
+        e_object_del(E_OBJECT(dia->dia));
+        dia->dia = NULL;
      }
    E_FREE(dia->color);
    E_FREE(dia);
@@ -147,3 +143,4 @@ _e_color_dialog_dia_del(void *obj)
    cdia->dia = NULL;
    e_object_del(E_OBJECT(cdia));
 }
+
