@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 typedef struct _E_Gadcon_Popup E_Gadcon_Popup;
@@ -19,6 +16,8 @@ struct _E_Gadcon_Popup
    E_Gadcon_Client     *gcc;
    Evas_Coord		w, h;
    Evas_Object	       *o_bg;
+   Evas_Object        *content;
+   Ecore_Event_Handler *autoclose_handlers[2];
 
    Eina_Bool            pinned : 1;
    Eina_Bool            gadcon_lock : 1;
