@@ -1,35 +1,36 @@
 #include "e.h"
 
-struct _E_Config_Dialog_Data 
+struct _E_Config_Dialog_Data
 {
-   E_Shelf *es;
+   E_Shelf        *es;
    E_Config_Shelf *escfg;
 
-   Evas_Object *o_autohide, *o_desk_list;
-   Eina_List *autohide_list, *desk_list;
+   Evas_Object    *o_autohide, *o_desk_list, *o_overlap;
+   Eina_List      *autohide_list, *desk_list;
 
-   int layer, overlap;
-   int orient, fit_along;
-   int size;
-   const char *style;
-   int autohide, autohide_action;
-   double hide_timeout, hide_duration;
-   int desk_show_mode;
+   int             layer, overlap;
+   int             orient, fit_along;
+   int             size;
+   const char     *style;
+   int             autohide, autohide_show_action;
+   double          hide_timeout, hide_duration;
+   int             desk_show_mode;
+   Eina_List      *handlers;
 };
 
 /* local function prototypes */
-static void *_create_data(E_Config_Dialog *cfd);
-static void _fill_data(E_Config_Dialog_Data *cfdata);
-static void _free_data(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata);
+static void        *_create_data(E_Config_Dialog *cfd);
+static void         _fill_data(E_Config_Dialog_Data *cfdata);
+static int          _basic_check_changed(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata);
+static void         _free_data(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata);
 static Evas_Object *_basic_create(E_Config_Dialog *cfd __UNUSED__, Evas *evas, E_Config_Dialog_Data *cfdata);
-static int _basic_apply(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata);
-static void _fill_styles(E_Config_Dialog_Data *cfdata, Evas_Object *obj);
-static void _cb_set_contents(void *data, void *data2 __UNUSED__);
-static void _cb_autohide_change(void *data, Evas_Object *obj __UNUSED__);
-static void _fill_desks(E_Config_Dialog_Data *cfdata);
+static int          _basic_apply(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata);
+static void         _fill_styles(E_Config_Dialog_Data *cfdata, Evas_Object *obj);
+static void         _cb_autohide_change(void *data, Evas_Object *obj __UNUSED__);
+static void         _fill_desks(E_Config_Dialog_Data *cfdata);
 
-EAPI void 
-e_int_shelf_config(E_Shelf *es) 
+EAPI void
+e_int_shelf_config(E_Shelf *es)
 {
    E_Config_Dialog_View *v;
 
@@ -39,39 +40,54 @@ e_int_shelf_config(E_Shelf *es)
    v->free_cfdata = _free_data;
    v->basic.create_widgets = _basic_create;
    v->basic.apply_cfdata = _basic_apply;
+   v->basic.check_changed = _basic_check_changed;
 
-   es->config_dialog = 
-     e_config_dialog_new(es->zone->container, _("Shelf Settings"), 
-                         "E", "_shelf_config_dialog", 
+   es->config_dialog =
+     e_config_dialog_new(es->zone->container, _("Shelf Settings"),
+                         "E", "_shelf_config_dialog",
                          "preferences-desktop-shelf", 0, v, es);
    e_win_centered_set(es->config_dialog->dia->win, EINA_TRUE);
 }
 
 /* local functions */
+static Eina_Bool
+_shelf_event_add(E_Config_Dialog_Data *cfdata, int type __UNUSED__, E_Event_Shelf *ev)
+{
+   if (ev->shelf->cfg == cfdata->escfg)
+     cfdata->es = ev->shelf;
+   return ECORE_CALLBACK_RENEW;
+}
+
+static Eina_Bool
+_shelf_event_del(E_Config_Dialog_Data *cfdata, int type __UNUSED__, E_Event_Shelf *ev)
+{
+   if (ev->shelf == cfdata->es)
+     cfdata->es = NULL;
+   return ECORE_CALLBACK_RENEW;
+}
+
 static void *
-_create_data(E_Config_Dialog *cfd) 
+_create_data(E_Config_Dialog *cfd)
 {
    E_Config_Dialog_Data *cfdata;
 
    cfdata = E_NEW(E_Config_Dialog_Data, 1);
    cfdata->es = cfd->data;
    cfdata->escfg = cfdata->es->cfg;
+   E_LIST_HANDLER_APPEND(cfdata->handlers, E_EVENT_SHELF_ADD, _shelf_event_add, cfdata);
+   E_LIST_HANDLER_APPEND(cfdata->handlers, E_EVENT_SHELF_DEL, _shelf_event_del, cfdata);
    _fill_data(cfdata);
    return cfdata;
 }
 
-static void 
-_fill_data(E_Config_Dialog_Data *cfdata) 
+static void
+_fill_data(E_Config_Dialog_Data *cfdata)
 {
    /* stacking */
-   if ((!cfdata->escfg->popup) && (cfdata->escfg->layer == 1))
-     cfdata->layer = 0;
-   else if ((cfdata->escfg->popup) && (cfdata->escfg->layer == 0))
-     cfdata->layer = 1;
-   else if ((cfdata->escfg->popup) && (cfdata->escfg->layer == 200))
-     cfdata->layer = 2;
+   if (cfdata->escfg->popup)
+     cfdata->layer = 1 + (!!cfdata->escfg->layer);
    else
-     cfdata->layer = 2;
+     cfdata->layer = 0;
    cfdata->overlap = cfdata->escfg->overlap;
 
    /* position */
@@ -82,14 +98,14 @@ _fill_data(E_Config_Dialog_Data *cfdata)
    cfdata->size = cfdata->escfg->size;
 
    /* style */
-   if (cfdata->escfg->style) 
+   if (cfdata->escfg->style)
      cfdata->style = eina_stringshare_ref(cfdata->escfg->style);
    else
      cfdata->style = eina_stringshare_add("");
 
    /* autohide */
    cfdata->autohide = cfdata->escfg->autohide;
-   cfdata->autohide_action = cfdata->escfg->autohide_show_action;
+   cfdata->autohide_show_action = cfdata->escfg->autohide_show_action;
    cfdata->hide_timeout = cfdata->escfg->hide_timeout;
    cfdata->hide_duration = cfdata->escfg->hide_duration;
 
@@ -98,20 +114,47 @@ _fill_data(E_Config_Dialog_Data *cfdata)
    cfdata->desk_list = cfdata->escfg->desk_list;
 }
 
-static void 
-_free_data(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata) 
+static int
+_basic_check_changed(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata)
+{
+   if (cfdata->escfg->popup)
+     {
+        if (cfdata->layer != 1 + (!!cfdata->escfg->layer)) return 1;
+     }
+   else
+     {
+        if (cfdata->layer) return 1;
+     }
+#define CHECK(X) if (cfdata->X != cfdata->escfg->X) return 1
+   CHECK(overlap);
+   CHECK(orient);
+   CHECK(fit_along);
+   CHECK(size);
+   CHECK(style);
+   CHECK(autohide);
+   CHECK(autohide_show_action);
+   CHECK(desk_show_mode);
+   CHECK(desk_list);
+   if (fabs(cfdata->hide_timeout - cfdata->escfg->hide_timeout) > 0.19) return 1;
+   if (fabs(cfdata->hide_duration - cfdata->escfg->hide_duration) > 0.04) return 1;
+   return 0;
+}
+
+static void
+_free_data(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata)
 {
    eina_list_free(cfdata->autohide_list);
 
-   if (cfdata->style) eina_stringshare_del(cfdata->style);
+   eina_stringshare_del(cfdata->style);
    cfdata->style = NULL;
 
+   E_FREE_LIST(cfdata->handlers, ecore_event_handler_del);
    cfdata->es->config_dialog = NULL;
    E_FREE(cfdata);
 }
 
 static Evas_Object *
-_basic_create(E_Config_Dialog *cfd __UNUSED__, Evas *evas, E_Config_Dialog_Data *cfdata) 
+_basic_create(E_Config_Dialog *cfd __UNUSED__, Evas *evas, E_Config_Dialog_Data *cfdata)
 {
    Evas_Object *otb, *ol, *ow;
    E_Radio_Group *rg;
@@ -127,63 +170,60 @@ _basic_create(E_Config_Dialog *cfd __UNUSED__, Evas *evas, E_Config_Dialog_Data
    e_widget_list_object_append(ol, ow, 1, 1, 0.5);
    ow = e_widget_radio_add(evas, _("Below Everything"), 0, rg);
    e_widget_list_object_append(ol, ow, 1, 1, 0.5);
-   ow = e_widget_check_add(evas, _("Allow windows to overlap the shelf"), 
-                           &(cfdata->overlap));
-   e_widget_list_object_append(ol, ow, 1, 1, 0.5);
-   e_widget_toolbook_page_append(otb, NULL, _("Stacking"), ol, 
+  e_widget_toolbook_page_append(otb, NULL, _("Stacking"), ol,
                                  1, 0, 1, 0, 0.5, 0.0);
 
    /* position */
    ol = e_widget_table_add(evas, 1);
    rg = e_widget_radio_group_new(&(cfdata->orient));
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-left", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-left",
                                 24, 24, E_GADCON_ORIENT_LEFT, rg);
    e_widget_table_object_append(ol, ow, 0, 2, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-right", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-right",
                                 24, 24, E_GADCON_ORIENT_RIGHT, rg);
    e_widget_table_object_append(ol, ow, 2, 2, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-top", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-top",
                                 24, 24, E_GADCON_ORIENT_TOP, rg);
    e_widget_table_object_append(ol, ow, 1, 0, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-bottom", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-bottom",
                                 24, 24, E_GADCON_ORIENT_BOTTOM, rg);
    e_widget_table_object_append(ol, ow, 1, 4, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-top-left", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-top-left",
                                 24, 24, E_GADCON_ORIENT_CORNER_TL, rg);
    e_widget_table_object_append(ol, ow, 0, 0, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-top-right", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-top-right",
                                 24, 24, E_GADCON_ORIENT_CORNER_TR, rg);
    e_widget_table_object_append(ol, ow, 2, 0, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-bottom-left", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-bottom-left",
                                 24, 24, E_GADCON_ORIENT_CORNER_BL, rg);
    e_widget_table_object_append(ol, ow, 0, 4, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-bottom-right", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-bottom-right",
                                 24, 24, E_GADCON_ORIENT_CORNER_BR, rg);
    e_widget_table_object_append(ol, ow, 2, 4, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-left-top", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-left-top",
                                 24, 24, E_GADCON_ORIENT_CORNER_LT, rg);
    e_widget_table_object_append(ol, ow, 0, 1, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-right-top", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-right-top",
                                 24, 24, E_GADCON_ORIENT_CORNER_RT, rg);
    e_widget_table_object_append(ol, ow, 2, 1, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-left-bottom", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-left-bottom",
                                 24, 24, E_GADCON_ORIENT_CORNER_LB, rg);
    e_widget_table_object_append(ol, ow, 0, 3, 1, 1, 1, 1, 1, 1);
-   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-right-bottom", 
+   ow = e_widget_radio_icon_add(evas, NULL, "preferences-position-right-bottom",
                                 24, 24, E_GADCON_ORIENT_CORNER_RB, rg);
    e_widget_table_object_append(ol, ow, 2, 3, 1, 1, 1, 1, 1, 1);
-   e_widget_toolbook_page_append(otb, NULL, _("Position"), ol, 
+   e_widget_toolbook_page_append(otb, NULL, _("Position"), ol,
                                  1, 0, 1, 0, 0.5, 0.0);
 
    /* size */
    ol = e_widget_list_add(evas, 0, 0);
-   ow = e_widget_slider_add(evas, 1, 0, _("Height (%3.0f pixels)"), 4, 120, 4, 0, 
+   ow = e_widget_slider_add(evas, 1, 0, _("%1.0f pixels"), 4, 256, 4, 0,
                             NULL, &(cfdata->size), 100);
    e_widget_list_object_append(ol, ow, 1, 1, 0.5);
-   ow = e_widget_check_add(evas, _("Shrink to Content Width"), 
+   ow = e_widget_check_add(evas, _("Shrink to Content Width"),
                            &(cfdata->fit_along));
    e_widget_list_object_append(ol, ow, 1, 1, 0.5);
-   e_widget_toolbook_page_append(otb, NULL, _("Size"), ol, 
+   e_widget_toolbook_page_append(otb, NULL, _("Size"), ol,
                                  1, 0, 1, 0, 0.5, 0.0);
 
    /* style */
@@ -191,17 +231,17 @@ _basic_create(E_Config_Dialog *cfd __UNUSED__, Evas *evas, E_Config_Dialog_Data
    ow = e_widget_ilist_add(evas, 60, 20, &(cfdata->style));
    _fill_styles(cfdata, ow);
    e_widget_list_object_append(ol, ow, 1, 1, 0.5);
-   e_widget_toolbook_page_append(otb, NULL, _("Style"), ol, 
+   e_widget_toolbook_page_append(otb, NULL, _("Style"), ol,
                                  1, 0, 1, 0, 0.5, 0.0);
 
    /* autohide */
    ol = e_widget_list_add(evas, 0, 0);
-   cfdata->o_autohide = 
+   cfdata->o_autohide =
      e_widget_check_add(evas, _("Auto-hide the shelf"), &(cfdata->autohide));
    e_widget_on_change_hook_set(cfdata->o_autohide, _cb_autohide_change, cfdata);
    e_widget_list_object_append(ol, cfdata->o_autohide, 1, 1, 0.5);
 
-   rg = e_widget_radio_group_new(&(cfdata->autohide_action));
+   rg = e_widget_radio_group_new(&(cfdata->autohide_show_action));
    ow = e_widget_radio_add(evas, _("Show on mouse in"), 0, rg);
    e_widget_disabled_set(ow, !cfdata->autohide);
    cfdata->autohide_list = eina_list_append(cfdata->autohide_list, ow);
@@ -215,7 +255,7 @@ _basic_create(E_Config_Dialog *cfd __UNUSED__, Evas *evas, E_Config_Dialog_Data
    cfdata->autohide_list = eina_list_append(cfdata->autohide_list, ow);
    e_widget_disabled_set(ow, !cfdata->autohide);
    e_widget_list_object_append(ol, ow, 1, 1, 0.5);
-   ow = e_widget_slider_add(evas, 1, 0, _("%.1f seconds"), 0.2, 6.0, 0.2, 0, 
+   ow = e_widget_slider_add(evas, 1, 0, _("%.1f seconds"), 0.2, 6.0, 0.2, 0,
                             &(cfdata->hide_timeout), NULL, 100);
    cfdata->autohide_list = eina_list_append(cfdata->autohide_list, ow);
    e_widget_disabled_set(ow, !cfdata->autohide);
@@ -225,12 +265,17 @@ _basic_create(E_Config_Dialog *cfd __UNUSED__, Evas *evas, E_Config_Dialog_Data
    cfdata->autohide_list = eina_list_append(cfdata->autohide_list, ow);
    e_widget_disabled_set(ow, !cfdata->autohide);
    e_widget_list_object_append(ol, ow, 1, 1, 0.5);
-   ow = e_widget_slider_add(evas, 1, 0, _("%.1f seconds"), 0.2, 6.0, 0.2, 0, 
+   ow = e_widget_slider_add(evas, 1, 0, _("%.2f seconds"), 0.05, 6.0, 0.05, 0,
                             &(cfdata->hide_duration), NULL, 100);
    cfdata->autohide_list = eina_list_append(cfdata->autohide_list, ow);
    e_widget_disabled_set(ow, !cfdata->autohide);
    e_widget_list_object_append(ol, ow, 1, 1, 0.5);
-   e_widget_toolbook_page_append(otb, NULL, _("Auto Hide"), ol, 
+   ow = e_widget_check_add(evas, _("Don't adjust windows when overlapping the shelf"),
+                           &(cfdata->overlap));
+   e_widget_disabled_set(ow, ((!cfdata->autohide) || (!e_config->border_fix_on_shelf_toggle)));
+   cfdata->o_overlap = ow;
+   e_widget_list_object_append(ol, ow, 1, 1, 0.5);
+   e_widget_toolbook_page_append(otb, NULL, _("Auto Hide"), ol,
                                  1, 0, 1, 0, 0.5, 0.0);
 
    /* Desktop */
@@ -245,85 +290,70 @@ _basic_create(E_Config_Dialog *cfd __UNUSED__, Evas *evas, E_Config_Dialog_Data
    e_widget_ilist_multi_select_set(cfdata->o_desk_list, EINA_TRUE);
    _fill_desks(cfdata);
    e_widget_list_object_append(ol, cfdata->o_desk_list, 1, 1, 0.5);
-   e_widget_toolbook_page_append(otb, NULL, _("Desktop"), ol, 
+   e_widget_toolbook_page_append(otb, NULL, _("Desktop"), ol,
                                  1, 0, 1, 0, 0.5, 0.0);
 
    e_widget_toolbook_page_show(otb, 0);
    return otb;
 }
 
-static int 
-_basic_apply(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata) 
+static int
+_basic_apply(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
 {
    E_Config_Shelf_Desk *sd;
-   int restart;
+   int recreate = 0;
 
-   if (!cfdata->escfg->style) 
-     {
-        cfdata->escfg->style = eina_stringshare_ref(cfdata->style);
-        e_shelf_style_set(cfdata->es, cfdata->style);
-     }
-   else if ((cfdata->escfg->style) && 
-            (strcmp(cfdata->escfg->style, cfdata->style)))
-     {
-        if (cfdata->escfg->style) eina_stringshare_del(cfdata->escfg->style);
-        cfdata->escfg->style = eina_stringshare_ref(cfdata->style);
-        e_shelf_style_set(cfdata->es, cfdata->style);
-     }
-
-   if (cfdata->escfg->orient != cfdata->orient) 
+   if (cfdata->escfg->orient != cfdata->orient)
      {
         cfdata->escfg->orient = cfdata->orient;
-        e_shelf_orient(cfdata->es, cfdata->orient);
-        e_shelf_position_calc(cfdata->es);
-        restart = 1;
+        recreate = 1;
      }
 
-   if (cfdata->escfg->fit_along != cfdata->fit_along) 
+   if (cfdata->escfg->fit_along != cfdata->fit_along)
      {
         cfdata->escfg->fit_along = cfdata->fit_along;
         cfdata->es->fit_along = cfdata->fit_along;
-        restart = 1;
+        recreate = 1;
      }
 
-   if (cfdata->escfg->size != cfdata->size) 
+   if (cfdata->escfg->size != cfdata->size)
      {
         cfdata->escfg->size = cfdata->size;
         cfdata->es->size = cfdata->size;
-        restart = 1;
+        recreate = 1;
      }
 
-   if (cfdata->layer == 0) 
+   if (cfdata->layer == 0)
      {
-        if ((cfdata->escfg->popup != 0) || (cfdata->escfg->layer != 1)) 
+        if ((cfdata->escfg->popup != 0) || (cfdata->escfg->layer != 1))
           {
              cfdata->escfg->popup = 0;
-             cfdata->escfg->layer = 1;
-             restart = 1;
+             cfdata->escfg->layer = E_COMP_CANVAS_LAYER_DESKTOP_TOP;
+             recreate = 1;
           }
      }
-   else if (cfdata->layer == 1) 
+   else if (cfdata->layer == 1)
      {
-        if ((cfdata->escfg->popup != 0) || (cfdata->escfg->layer != 1)) 
+        if ((cfdata->escfg->popup != 1) || (cfdata->escfg->layer != 0))
           {
              cfdata->escfg->popup = 1;
              cfdata->escfg->layer = 0;
-             restart = 1;
+             recreate = 1;
           }
      }
-   else if (cfdata->layer == 2) 
+   else if (cfdata->layer == 2)
      {
-        if ((cfdata->escfg->popup != 1) || (cfdata->escfg->layer != 200)) 
+        if ((cfdata->escfg->popup != 1) || (cfdata->escfg->layer != E_LAYER_ABOVE))
           {
              cfdata->escfg->popup = 1;
-             cfdata->escfg->layer = 200;
-             restart = 1;
+             cfdata->escfg->layer = E_LAYER_ABOVE;
+             recreate = 1;
           }
      }
 
    cfdata->escfg->overlap = cfdata->overlap;
-   cfdata->escfg->autohide = cfdata->autohide;
-   cfdata->escfg->autohide_show_action = cfdata->autohide_action;
+   e_shelf_autohide_set(cfdata->es, cfdata->autohide + (cfdata->autohide * cfdata->autohide_show_action));
+   cfdata->escfg->autohide_show_action = cfdata->autohide_show_action;
    cfdata->escfg->hide_timeout = cfdata->hide_timeout;
    cfdata->escfg->hide_duration = cfdata->hide_duration;
    cfdata->escfg->desk_show_mode = cfdata->desk_show_mode;
@@ -332,13 +362,13 @@ _basic_apply(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
      E_FREE(sd);
    cfdata->escfg->desk_list = NULL;
 
-   if (cfdata->desk_show_mode) 
+   if (cfdata->desk_show_mode)
      {
-        Eina_List *l;
+        const Eina_List *l;
         const E_Ilist_Item *it;
         int idx = -1;
 
-        EINA_LIST_FOREACH(e_widget_ilist_items_get(cfdata->o_desk_list), l, it) 
+        EINA_LIST_FOREACH(e_widget_ilist_items_get(cfdata->o_desk_list), l, it)
           {
              E_Desk *desk;
 
@@ -348,41 +378,50 @@ _basic_apply(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
              sd = E_NEW(E_Config_Shelf_Desk, 1);
              sd->x = desk->x;
              sd->y = desk->y;
-             cfdata->escfg->desk_list = 
+             cfdata->escfg->desk_list =
                eina_list_append(cfdata->escfg->desk_list, sd);
           }
      }
 
-   if (restart) 
+   e_gadcon_unpopulate(cfdata->es->gadcon);
+   if (!cfdata->escfg->style)
+     {
+        cfdata->escfg->style = eina_stringshare_ref(cfdata->style);
+        e_shelf_style_set(cfdata->es, cfdata->style);
+     }
+   else if ((cfdata->escfg->style) &&
+            (cfdata->escfg->style != cfdata->style))
+     {
+        eina_stringshare_replace(&cfdata->escfg->style, cfdata->style);
+        e_shelf_style_set(cfdata->es, cfdata->style);
+     }
+   if (recreate)
      {
         E_Zone *zone;
+        E_Config_Shelf *cf_es;
 
         zone = cfdata->es->zone;
+        cf_es = cfdata->es->cfg;
         cfdata->es->config_dialog = NULL;
+        e_shelf_hide(cfdata->es);
         e_object_del(E_OBJECT(cfdata->es));
 
-        cfdata->es = 
-          e_shelf_zone_new(zone, cfdata->escfg->name, 
-                           cfdata->escfg->style, cfdata->escfg->popup, 
-                           cfdata->escfg->layer, cfdata->escfg->id);
-        cfdata->es->cfg = cfdata->escfg;
-        cfdata->es->fit_along = cfdata->escfg->fit_along;
-        e_shelf_orient(cfdata->es, cfdata->escfg->orient);
-        e_shelf_position_calc(cfdata->es);
-        e_shelf_populate(cfdata->es);
+        cfdata->es = e_shelf_config_new(zone, cf_es);
+        cfdata->es->config_dialog = cfd;
      }
+   else
+     e_gadcon_populate(cfdata->es->gadcon);
 
-   if (cfdata->escfg->desk_show_mode) 
+   if (cfdata->escfg->desk_show_mode)
      {
         E_Desk *desk;
         Eina_List *l;
-        E_Config_Shelf_Desk *sd;
-        int show;
+        int show = 0;
 
         desk = e_desk_current_get(cfdata->es->zone);
-        EINA_LIST_FOREACH(cfdata->escfg->desk_list, l, sd) 
+        EINA_LIST_FOREACH(cfdata->escfg->desk_list, l, sd)
           {
-             if ((desk->x == sd->x) && (desk->y == sd->y)) 
+             if ((desk->x == sd->x) && (desk->y == sd->y))
                {
                   show = 1;
                   break;
@@ -405,12 +444,13 @@ _basic_apply(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
    return 1;
 }
 
-static void 
-_fill_styles(E_Config_Dialog_Data *cfdata, Evas_Object *obj) 
+static void
+_fill_styles(E_Config_Dialog_Data *cfdata, Evas_Object *obj)
 {
    Evas *evas;
    Eina_List *l, *styles;
    char *style;
+   const char *str;
    int mw, n = 0;
 
    evas = evas_object_evas_get(obj);
@@ -420,10 +460,10 @@ _fill_styles(E_Config_Dialog_Data *cfdata, Evas_Object *obj)
    e_widget_ilist_clear(obj);
 
    styles = e_theme_shelf_list();
-   EINA_LIST_FOREACH(styles, l, style) 
+   EINA_LIST_FOREACH(styles, l, style)
      {
         Evas_Object *thumb, *ow;
-        char buff[PATH_MAX];
+        char buff[4096];
 
         thumb = e_livethumb_add(evas);
         e_livethumb_vsize_set(thumb, 120, 40);
@@ -433,7 +473,7 @@ _fill_styles(E_Config_Dialog_Data *cfdata, Evas_Object *obj)
         e_livethumb_thumb_set(thumb, ow);
         e_widget_ilist_append(obj, thumb, style, NULL, NULL, style);
         if (!strcmp(cfdata->style, style))
-	  e_widget_ilist_selected_set(obj, n);
+          e_widget_ilist_selected_set(obj, n);
         n++;
      }
 
@@ -444,20 +484,13 @@ _fill_styles(E_Config_Dialog_Data *cfdata, Evas_Object *obj)
    e_widget_ilist_thaw(obj);
    edje_thaw();
    evas_event_thaw(evas);
+
+   EINA_LIST_FREE(styles, str)
+     eina_stringshare_del(str);
 }
 
-static void 
-_cb_set_contents(void *data, void *data2 __UNUSED__) 
-{
-   E_Config_Dialog_Data *cfdata;
-
-   if (!(cfdata = data)) return;
-   if (!cfdata->es->gadcon->config_dialog)
-     e_int_gadcon_config_shelf(cfdata->es->gadcon);
-}
-
-static void 
-_cb_autohide_change(void *data, Evas_Object *obj __UNUSED__) 
+static void
+_cb_autohide_change(void *data, Evas_Object *obj __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
    Eina_List *l;
@@ -466,10 +499,12 @@ _cb_autohide_change(void *data, Evas_Object *obj __UNUSED__)
    if (!(cfdata = data)) return;
    EINA_LIST_FOREACH(cfdata->autohide_list, l, ow)
      e_widget_disabled_set(ow, !cfdata->autohide);
+   
+   e_widget_disabled_set(cfdata->o_overlap, ((!cfdata->autohide) || (!e_config->border_fix_on_shelf_toggle)));
 }
 
-static void 
-_fill_desks(E_Config_Dialog_Data *cfdata) 
+static void
+_fill_desks(E_Config_Dialog_Data *cfdata)
 {
    Evas *evas;
    int mw, x, y;
@@ -482,18 +517,18 @@ _fill_desks(E_Config_Dialog_Data *cfdata)
    e_widget_ilist_clear(cfdata->o_desk_list);
 
    for (y = 0; y < e_config->zone_desks_y_count; y++)
-     for (x = 0; x < e_config->zone_desks_x_count; x++) 
+     for (x = 0; x < e_config->zone_desks_x_count; x++)
        {
           E_Desk *desk;
           Eina_List *l;
           E_Config_Shelf_Desk *sd;
 
           desk = e_desk_at_xy_get(cfdata->es->zone, x, y);
-          e_widget_ilist_append(cfdata->o_desk_list, NULL, desk->name, 
+          e_widget_ilist_append(cfdata->o_desk_list, NULL, desk->name,
                                 NULL, NULL, NULL);
           i++;
 
-          EINA_LIST_FOREACH(cfdata->desk_list, l, sd) 
+          EINA_LIST_FOREACH(cfdata->desk_list, l, sd)
             {
                if ((sd->x != x) || (sd->y != y)) continue;
                e_widget_ilist_multi_select(cfdata->o_desk_list, i);
@@ -509,3 +544,4 @@ _fill_desks(E_Config_Dialog_Data *cfdata)
    edje_thaw();
    evas_event_thaw(evas);
 }
+
