@@ -28,71 +28,58 @@ static Eet_Data_Descriptor *_e_ipc_3int_3str_list_edd = NULL;
 static Eet_Data_Descriptor *_e_ipc_str_4int_edd = NULL;
 static Eet_Data_Descriptor *_e_ipc_str_4int_list_edd = NULL;
 
-static void *
-_e_ipc_codec_eina_hash_add(void *hash, const void *key, void *data)
-{
-   Eina_Hash *result = hash;
-
-   if (!result) result = eina_hash_string_superfast_new(NULL);
-   if (!result) return NULL;
-
-   eina_hash_add(result, key, data);
-   return result;
-}
-
-#define E_IPC_DD_NEW(str, typ) \
-   eet_data_descriptor_new(str, sizeof(typ), \
-			      (void *(*) (void *))eina_list_next, \
-			      (void *(*) (void *, void *))eina_list_append, \
-			      (void *(*) (void *))eina_list_data_get, \
-			      (void *(*) (void *))eina_list_free, \
-                              (void  (*) (void *, int (*) (void *, const char *, void *, void *), void *))eina_hash_foreach, \
-			      (void *(*) (void *, const char *, void *))_e_ipc_codec_eina_hash_add, \
-			      (void  (*) (void *))eina_hash_free)
+#define E_IPC_DD(Edd, Eddc, Name, Type) \
+  Eddc.name = Name;                     \
+  Eddc.size = sizeof (Type);            \
+  Edd = eet_data_descriptor_stream_new(&Eddc);
 
 /* externally accessible functions */
-EAPI int
+EINTERN int
 e_ipc_codec_init(void)
 {
-   _e_ipc_int_edd = E_IPC_DD_NEW("int", E_Ipc_Int);
+   Eet_Data_Descriptor_Class eddc;
+
+   if (!eet_eina_stream_data_descriptor_class_set(&eddc, sizeof (eddc), "int", sizeof (E_Ipc_Int)))
+     return 0;
+   _e_ipc_int_edd = eet_data_descriptor_stream_new(&eddc);
    E_CONFIG_VAL(_e_ipc_int_edd, E_Ipc_Int, val, INT);
 
-   _e_ipc_double_edd = E_IPC_DD_NEW("double", E_Ipc_Double);
+   E_IPC_DD(_e_ipc_double_edd, eddc, "double", E_Ipc_Double);
    E_CONFIG_VAL(_e_ipc_double_edd, E_Ipc_Double, val, DOUBLE);
-   
-   _e_ipc_2int_edd = E_IPC_DD_NEW("2int", E_Ipc_2Int);
+
+   E_IPC_DD(_e_ipc_2int_edd, eddc, "2int", E_Ipc_2Int);
    E_CONFIG_VAL(_e_ipc_2int_edd, E_Ipc_2Int, val1, INT);
    E_CONFIG_VAL(_e_ipc_2int_edd, E_Ipc_2Int, val2, INT);
 
-   _e_ipc_str_edd = E_IPC_DD_NEW("str", E_Ipc_Str);
+   E_IPC_DD(_e_ipc_str_edd, eddc, "str", E_Ipc_Str);
    E_CONFIG_VAL(_e_ipc_str_edd, E_Ipc_Str, str, STR);
 
-   _e_ipc_str_list_edd = E_IPC_DD_NEW("str_list", E_Ipc_List);
+   E_IPC_DD(_e_ipc_str_list_edd, eddc, "str_list", E_Ipc_List);
    E_CONFIG_LIST(_e_ipc_str_list_edd, E_Ipc_List, list, _e_ipc_str_edd);
 
-   _e_ipc_2str_edd = E_IPC_DD_NEW("2str", E_Ipc_2Str);
+   E_IPC_DD(_e_ipc_2str_edd, eddc, "2str", E_Ipc_2Str);
    E_CONFIG_VAL(_e_ipc_2str_edd, E_Ipc_2Str, str1, STR);
    E_CONFIG_VAL(_e_ipc_2str_edd, E_Ipc_2Str, str2, STR);
-   
-   _e_ipc_2str_list_edd = E_IPC_DD_NEW("2str_list", E_Ipc_List);
+
+   E_IPC_DD(_e_ipc_2str_list_edd, eddc, "2str_list", E_Ipc_List);
    E_CONFIG_LIST(_e_ipc_2str_list_edd, E_Ipc_List, list, _e_ipc_2str_edd);
 
-   _e_ipc_str_int_edd = E_IPC_DD_NEW("str_int", E_Ipc_Str_Int);
+   E_IPC_DD(_e_ipc_str_int_edd, eddc, "str_int", E_Ipc_Str_Int);
    E_CONFIG_VAL(_e_ipc_str_int_edd, E_Ipc_Str_Int, str, STR);
    E_CONFIG_VAL(_e_ipc_str_int_edd, E_Ipc_Str_Int, val, INT);
-   
-   _e_ipc_str_int_list_edd = E_IPC_DD_NEW("str_int_list", E_Ipc_List);
+
+   E_IPC_DD(_e_ipc_str_int_list_edd, eddc, "str_int_list", E_Ipc_List);
    E_CONFIG_LIST(_e_ipc_str_int_list_edd, E_Ipc_List, list, _e_ipc_str_int_edd);
 
-   _e_ipc_2str_int_edd = E_IPC_DD_NEW("2str_int", E_Ipc_2Str_Int);
+   E_IPC_DD(_e_ipc_2str_int_edd, eddc, "2str_int", E_Ipc_2Str_Int);
    E_CONFIG_VAL(_e_ipc_2str_int_edd, E_Ipc_2Str_Int, str1, STR);
    E_CONFIG_VAL(_e_ipc_2str_int_edd, E_Ipc_2Str_Int, str2, STR);
    E_CONFIG_VAL(_e_ipc_2str_int_edd, E_Ipc_2Str_Int, val, INT);
-   
-   _e_ipc_2str_int_list_edd = E_IPC_DD_NEW("2str_int_list", E_Ipc_List);
+
+   E_IPC_DD(_e_ipc_2str_int_list_edd, eddc, "2str_int_list", E_Ipc_List);
    E_CONFIG_LIST(_e_ipc_2str_int_list_edd, E_Ipc_List, list, _e_ipc_2str_int_edd);
-   
-   _e_ipc_4int_2str_edd = E_IPC_DD_NEW("4int_2str", E_Ipc_4Int_2Str);
+
+   E_IPC_DD(_e_ipc_4int_2str_edd, eddc, "4int_2str", E_Ipc_4Int_2Str);
    E_CONFIG_VAL(_e_ipc_4int_2str_edd, E_Ipc_4Int_2Str, val1, INT);
    E_CONFIG_VAL(_e_ipc_4int_2str_edd, E_Ipc_4Int_2Str, val2, INT);
    E_CONFIG_VAL(_e_ipc_4int_2str_edd, E_Ipc_4Int_2Str, val3, INT);
@@ -100,10 +87,10 @@ e_ipc_codec_init(void)
    E_CONFIG_VAL(_e_ipc_4int_2str_edd, E_Ipc_4Int_2Str, str1, STR);
    E_CONFIG_VAL(_e_ipc_4int_2str_edd, E_Ipc_4Int_2Str, str2, STR);
 
-   _e_ipc_4int_2str_list_edd = E_IPC_DD_NEW("4int_2str_list", E_Ipc_List);
+   E_IPC_DD(_e_ipc_4int_2str_list_edd, eddc, "4int_2str_list", E_Ipc_List);
    E_CONFIG_LIST(_e_ipc_4int_2str_list_edd, E_Ipc_List, list, _e_ipc_4int_2str_edd);
 
-   _e_ipc_5int_2str_edd = E_IPC_DD_NEW("5int_2str", E_Ipc_5Int_2Str);
+   E_IPC_DD(_e_ipc_5int_2str_edd, eddc, "5int_2str", E_Ipc_5Int_2Str);
    E_CONFIG_VAL(_e_ipc_5int_2str_edd, E_Ipc_5Int_2Str, val1, INT);
    E_CONFIG_VAL(_e_ipc_5int_2str_edd, E_Ipc_5Int_2Str, val2, INT);
    E_CONFIG_VAL(_e_ipc_5int_2str_edd, E_Ipc_5Int_2Str, val3, INT);
@@ -112,10 +99,10 @@ e_ipc_codec_init(void)
    E_CONFIG_VAL(_e_ipc_5int_2str_edd, E_Ipc_5Int_2Str, str1, STR);
    E_CONFIG_VAL(_e_ipc_5int_2str_edd, E_Ipc_5Int_2Str, str2, STR);
 
-   _e_ipc_5int_2str_list_edd = E_IPC_DD_NEW("5int_2str_list", E_Ipc_List);
+   E_IPC_DD(_e_ipc_5int_2str_list_edd, eddc, "5int_2str_list", E_Ipc_List);
    E_CONFIG_LIST(_e_ipc_5int_2str_list_edd, E_Ipc_List, list, _e_ipc_5int_2str_edd);
 
-   _e_ipc_3int_4str_edd = E_IPC_DD_NEW("3int_4str", E_Ipc_3Int_4Str);
+   E_IPC_DD(_e_ipc_3int_4str_edd, eddc, "3int_4str", E_Ipc_3Int_4Str);
    E_CONFIG_VAL(_e_ipc_3int_4str_edd, E_Ipc_3Int_4Str, val1, INT);
    E_CONFIG_VAL(_e_ipc_3int_4str_edd, E_Ipc_3Int_4Str, val2, INT);
    E_CONFIG_VAL(_e_ipc_3int_4str_edd, E_Ipc_3Int_4Str, val3, INT);
@@ -124,10 +111,10 @@ e_ipc_codec_init(void)
    E_CONFIG_VAL(_e_ipc_3int_4str_edd, E_Ipc_3Int_4Str, str3, STR);
    E_CONFIG_VAL(_e_ipc_3int_4str_edd, E_Ipc_3Int_4Str, str4, STR);
 
-   _e_ipc_3int_4str_list_edd = E_IPC_DD_NEW("3int_4str_list", E_Ipc_List);
+   E_IPC_DD(_e_ipc_3int_4str_list_edd, eddc, "3int_4str_list", E_Ipc_List);
    E_CONFIG_LIST(_e_ipc_3int_4str_list_edd, E_Ipc_List, list, _e_ipc_3int_4str_edd);
 
-   _e_ipc_3int_3str_edd = E_IPC_DD_NEW("3int_3str", E_Ipc_3Int_3Str);
+   E_IPC_DD(_e_ipc_3int_3str_edd, eddc, "3int_3str", E_Ipc_3Int_3Str);
    E_CONFIG_VAL(_e_ipc_3int_3str_edd, E_Ipc_3Int_3Str, val1, INT);
    E_CONFIG_VAL(_e_ipc_3int_3str_edd, E_Ipc_3Int_3Str, val2, INT);
    E_CONFIG_VAL(_e_ipc_3int_3str_edd, E_Ipc_3Int_3Str, val3, INT);
@@ -135,23 +122,23 @@ e_ipc_codec_init(void)
    E_CONFIG_VAL(_e_ipc_3int_3str_edd, E_Ipc_3Int_3Str, str2, STR);
    E_CONFIG_VAL(_e_ipc_3int_3str_edd, E_Ipc_3Int_3Str, str3, STR);
 
-   _e_ipc_3int_3str_list_edd = E_IPC_DD_NEW("3int_3str_list", E_Ipc_List);
+   E_IPC_DD(_e_ipc_3int_3str_list_edd, eddc, "3int_3str_list", E_Ipc_List);
    E_CONFIG_LIST(_e_ipc_3int_3str_list_edd, E_Ipc_List, list, _e_ipc_3int_3str_edd);
 
-   _e_ipc_str_4int_edd = E_IPC_DD_NEW("str_4int", E_Ipc_Str_4Int);
+   E_IPC_DD(_e_ipc_str_4int_edd, eddc, "str_4int", E_Ipc_Str_4Int);
    E_CONFIG_VAL(_e_ipc_str_4int_edd, E_Ipc_Str_4Int, str, STR);
    E_CONFIG_VAL(_e_ipc_str_4int_edd, E_Ipc_Str_4Int, val1, INT);
    E_CONFIG_VAL(_e_ipc_str_4int_edd, E_Ipc_Str_4Int, val2, INT);
    E_CONFIG_VAL(_e_ipc_str_4int_edd, E_Ipc_Str_4Int, val3, INT);
    E_CONFIG_VAL(_e_ipc_str_4int_edd, E_Ipc_Str_4Int, val4, INT);
 
-   _e_ipc_str_4int_list_edd = E_IPC_DD_NEW("str_4int_list", E_Ipc_List);
+   E_IPC_DD(_e_ipc_str_4int_list_edd, eddc, "str_4int_list", E_Ipc_List);
    E_CONFIG_LIST(_e_ipc_str_4int_list_edd, E_Ipc_List, list, _e_ipc_str_4int_edd);
 
    return 1;
 }
 
-EAPI void
+EINTERN void
 e_ipc_codec_shutdown(void)
 {
    E_CONFIG_DD_FREE(_e_ipc_int_edd);
@@ -181,7 +168,7 @@ EAPI int
 e_ipc_codec_int_dec(char *data, int bytes, int *dest)
 {
    E_Ipc_Int *dat;
-   
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_int_edd, data, bytes);
    if (!dat) return 0;
@@ -194,7 +181,7 @@ EAPI void *
 e_ipc_codec_int_enc(int val, int *size_ret)
 {
    E_Ipc_Int dat;
-   
+
    dat.val = val;
    return eet_data_descriptor_encode(_e_ipc_int_edd, &dat, size_ret);
 }
@@ -203,7 +190,7 @@ EAPI int
 e_ipc_codec_double_dec(char *data, int bytes, double *dest)
 {
    E_Ipc_Double *dat;
-   
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_double_edd, data, bytes);
    if (!dat) return 0;
@@ -216,7 +203,7 @@ EAPI void *
 e_ipc_codec_double_enc(double val, int *size_ret)
 {
    E_Ipc_Double dat;
-   
+
    dat.val = val;
    return eet_data_descriptor_encode(_e_ipc_double_edd, &dat, size_ret);
 }
@@ -225,7 +212,7 @@ EAPI int
 e_ipc_codec_2int_dec(char *data, int bytes, int *dest, int *dest2)
 {
    E_Ipc_2Int *dat;
-   
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_2int_edd, data, bytes);
    if (!dat) return 0;
@@ -239,7 +226,7 @@ EAPI void *
 e_ipc_codec_2int_enc(int val1, int val2, int *size_ret)
 {
    E_Ipc_2Int dat;
-   
+
    dat.val1 = val1;
    dat.val2 = val2;
    return eet_data_descriptor_encode(_e_ipc_2int_edd, &dat, size_ret);
@@ -249,7 +236,7 @@ EAPI int
 e_ipc_codec_str_dec(char *data, int bytes, char **dest)
 {
    E_Ipc_Str *dat;
-   
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_str_edd, data, bytes);
    if (!dat) return 0;
@@ -262,8 +249,8 @@ EAPI void *
 e_ipc_codec_str_enc(const char *str, int *size_ret)
 {
    E_Ipc_Str dat;
-   
-   dat.str = (char *) str;
+
+   dat.str = (char *)str;
    return eet_data_descriptor_encode(_e_ipc_str_edd, &dat, size_ret);
 }
 
@@ -271,7 +258,7 @@ EAPI int
 e_ipc_codec_2str_dec(char *data, int bytes, E_Ipc_2Str **dest)
 {
    E_Ipc_2Str *dat;
-   
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_2str_edd, data, bytes);
    if (!dat) return 0;
@@ -283,9 +270,9 @@ EAPI void *
 e_ipc_codec_2str_enc(const char *str1, const char *str2, int *size_ret)
 {
    E_Ipc_2Str dat;
-   
-   dat.str1 = (char *) str1;
-   dat.str2 = (char *) str2;
+
+   dat.str1 = (char *)str1;
+   dat.str2 = (char *)str2;
    return eet_data_descriptor_encode(_e_ipc_2str_edd, &dat, size_ret);
 }
 
@@ -293,7 +280,7 @@ EAPI int
 e_ipc_codec_2str_list_dec(char *data, int bytes, Eina_List **dest)
 {
    E_Ipc_List *dat;
-   
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_2str_list_edd, data, bytes);
    if (!dat) return 0;
@@ -315,23 +302,17 @@ e_ipc_codec_str_list_dec(char *data, int bytes, Eina_List **dest)
 {
    E_Ipc_List *dat;
    Eina_List *list = NULL, *l;
-   
+   E_Ipc_Str *str_node;
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_str_list_edd, data, bytes);
    if (!dat) return 0;
-   for (l = dat->list; l; l = l->next)
+   EINA_LIST_FOREACH(dat->list, l, str_node)
      {
-        E_Ipc_Str *str_node;
-	
-        str_node = l->data;
-	list = eina_list_append(list, str_node->str);
+        list = eina_list_append(list, str_node->str);
      }
    if (dest) *dest = list;
-   while (dat->list)
-     {
-	free(dat->list->data);
-	dat->list = eina_list_remove_list(dat->list, dat->list);
-     }
+   E_FREE_LIST(dat->list, free);
    free(dat);
    return 1;
 }
@@ -341,23 +322,19 @@ e_ipc_codec_str_list_enc(Eina_List *list, int *size_ret)
 {
    E_Ipc_List dat;
    Eina_List *l;
+   E_Ipc_Str *str_node;
+   char *str;
    void *data;
-   
+
    dat.list = NULL;
-   for (l = list; l; l = l->next)
+   EINA_LIST_FOREACH(list, l, str)
      {
-	E_Ipc_Str *str_node;
-	
-	str_node = malloc(sizeof(E_Ipc_Str));
-	str_node->str = l->data;
-	dat.list = eina_list_append(dat.list, str_node);
+        str_node = malloc(sizeof(E_Ipc_Str));
+        str_node->str = str;
+        dat.list = eina_list_append(dat.list, str_node);
      }
    data = eet_data_descriptor_encode(_e_ipc_str_list_edd, &dat, size_ret);
-   while (dat.list)
-     {
-	free(dat.list->data);
-	dat.list = eina_list_remove_list(dat.list, dat.list);
-     }
+   E_FREE_LIST(dat.list, free);
    return data;
 }
 
@@ -365,7 +342,7 @@ EAPI int
 e_ipc_codec_str_int_dec(char *data, int bytes, E_Ipc_Str_Int **dest)
 {
    E_Ipc_Str_Int *dat;
-   
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_str_int_edd, data, bytes);
    if (!dat) return 0;
@@ -377,8 +354,8 @@ EAPI void *
 e_ipc_codec_str_int_enc(const char *str, int val, int *size_ret)
 {
    E_Ipc_Str_Int dat;
-   
-   dat.str = (char *) str;
+
+   dat.str = (char *)str;
    dat.val = val;
    return eet_data_descriptor_encode(_e_ipc_str_int_edd, &dat, size_ret);
 }
@@ -387,7 +364,7 @@ EAPI int
 e_ipc_codec_str_int_list_dec(char *data, int bytes, Eina_List **dest)
 {
    E_Ipc_List *dat;
-   
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_str_int_list_edd, data, bytes);
    if (!dat) return 0;
@@ -408,7 +385,7 @@ EAPI int
 e_ipc_codec_2str_int_dec(char *data, int bytes, E_Ipc_2Str_Int **dest)
 {
    E_Ipc_2Str_Int *dat;
-   
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_2str_int_edd, data, bytes);
    if (!dat) return 0;
@@ -420,9 +397,9 @@ EAPI void *
 e_ipc_codec_2str_int_enc(const char *str1, const char *str2, int val, int *size_ret)
 {
    E_Ipc_2Str_Int dat;
-   
-   dat.str1 = (char *) str1;
-   dat.str2 = (char *) str2;
+
+   dat.str1 = (char *)str1;
+   dat.str2 = (char *)str2;
    dat.val = val;
    return eet_data_descriptor_encode(_e_ipc_2str_int_edd, &dat, size_ret);
 }
@@ -431,7 +408,7 @@ EAPI int
 e_ipc_codec_2str_int_list_dec(char *data, int bytes, Eina_List **dest)
 {
    E_Ipc_List *dat;
-   
+
    if (!data) return 0;
    dat = eet_data_descriptor_decode(_e_ipc_2str_int_list_edd, data, bytes);
    if (!dat) return 0;
@@ -469,9 +446,9 @@ e_ipc_codec_4int_2str_enc(int val1, int val2, int val3, int val4, const char *st
    dat.val2 = val2;
    dat.val3 = val3;
    dat.val4 = val4;
-   dat.str1 = (char *) str1;
-   dat.str2 = (char *) str2;
-   return eet_data_descriptor_encode(_e_ipc_4int_2str_edd, &dat, size_ret);   
+   dat.str1 = (char *)str1;
+   dat.str2 = (char *)str2;
+   return eet_data_descriptor_encode(_e_ipc_4int_2str_edd, &dat, size_ret);
 }
 
 EAPI int
@@ -517,9 +494,9 @@ e_ipc_codec_5int_2str_enc(int val1, int val2, int val3, int val4, int val5, cons
    dat.val3 = val3;
    dat.val4 = val4;
    dat.val5 = val5;
-   dat.str1 = (char *) str1;
-   dat.str2 = (char *) str2;
-   return eet_data_descriptor_encode(_e_ipc_5int_2str_edd, &dat, size_ret);   
+   dat.str1 = (char *)str1;
+   dat.str2 = (char *)str2;
+   return eet_data_descriptor_encode(_e_ipc_5int_2str_edd, &dat, size_ret);
 }
 
 EAPI int
@@ -563,11 +540,11 @@ e_ipc_codec_3int_4str_enc(int val1, int val2, int val3, const char *str1, const
    dat.val1 = val1;
    dat.val2 = val2;
    dat.val3 = val3;
-   dat.str1 = (char *) str1;
-   dat.str2 = (char *) str2;
-   dat.str3 = (char *) str3;
-   dat.str4 = (char *) str4;
-   return eet_data_descriptor_encode(_e_ipc_3int_4str_edd, &dat, size_ret);   
+   dat.str1 = (char *)str1;
+   dat.str2 = (char *)str2;
+   dat.str3 = (char *)str3;
+   dat.str4 = (char *)str4;
+   return eet_data_descriptor_encode(_e_ipc_3int_4str_edd, &dat, size_ret);
 }
 
 EAPI int
@@ -611,10 +588,10 @@ e_ipc_codec_3int_3str_enc(int val1, int val2, int val3, const char *str1, const
    dat.val1 = val1;
    dat.val2 = val2;
    dat.val3 = val3;
-   dat.str1 = (char *) str1;
-   dat.str2 = (char *) str2;
-   dat.str3 = (char *) str3;
-   return eet_data_descriptor_encode(_e_ipc_3int_3str_edd, &dat, size_ret);   
+   dat.str1 = (char *)str1;
+   dat.str2 = (char *)str2;
+   dat.str3 = (char *)str3;
+   return eet_data_descriptor_encode(_e_ipc_3int_3str_edd, &dat, size_ret);
 }
 
 EAPI int
@@ -641,27 +618,27 @@ e_ipc_codec_3int_3str_list_enc(Eina_List *list, int *size_ret)
 EAPI int
 e_ipc_codec_str_4int_dec(char *data, int bytes, E_Ipc_Str_4Int **dest)
 {
-  E_Ipc_Str_4Int *dat;
+   E_Ipc_Str_4Int *dat;
 
-  if (!data) return 0;
-  dat = eet_data_descriptor_decode(_e_ipc_str_4int_edd, data, bytes);
-  if (!dat) return 0;
-  if (dest) *dest = dat;
-  return 1;
+   if (!data) return 0;
+   dat = eet_data_descriptor_decode(_e_ipc_str_4int_edd, data, bytes);
+   if (!dat) return 0;
+   if (dest) *dest = dat;
+   return 1;
 }
 
 EAPI void *
 e_ipc_codec_str_4int_enc(const char *str1, int val1, int val2, int val3, int val4, int *size_ret)
 {
-  E_Ipc_Str_4Int dat;
+   E_Ipc_Str_4Int dat;
 
-  dat.str = (char *) str1;
-  dat.val1 = val1;
-  dat.val2 = val2;
-  dat.val3 = val3;
-  dat.val4 = val4;
+   dat.str = (char *)str1;
+   dat.val1 = val1;
+   dat.val2 = val2;
+   dat.val3 = val3;
+   dat.val4 = val4;
 
-  return eet_data_descriptor_encode(_e_ipc_str_4int_edd, &dat, size_ret);
+   return eet_data_descriptor_encode(_e_ipc_str_4int_edd, &dat, size_ret);
 }
 
 EAPI int
@@ -688,4 +665,3 @@ e_ipc_codec_str_4int_list_enc(Eina_List *list, int *size_ret)
 /* local subsystem globals */
 
 #endif
-
