@@ -1,9 +1,12 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifndef E_MOD_MAIN_H
 #define E_MOD_MAIN_H
 
+#ifdef HAVE_EEZE
+# include <Eeze.h>
+#else
+# include <Eldbus.h>
+#endif
+
 typedef struct _Config       Config;
 
 #define CHECK_NONE      0
@@ -16,6 +19,10 @@ typedef struct _Config       Config;
 #define NOSUBSYSTEM 1
 #define SUBSYSTEM 2
 
+#define SUSPEND 0
+#define HIBERNATE 1
+#define SHUTDOWN 2
+
 #define POPUP_DEBOUNCE_CYCLES  2
 
 struct _Config
@@ -25,12 +32,13 @@ struct _Config
    int              alert;	/* Alert on minutes remaining */
    int	            alert_p;    /* Alert on percentage remaining */
    int              alert_timeout;  /* Popup dismissal timeout */
+   int              suspend_below;  /* Suspend if battery drops below this level */
+   int              suspend_method; /* Method used to suspend the machine */
    int              force_mode; /* force use of batget or hal */
    /* just config state */
    E_Module        *module;
    E_Config_Dialog *config_dialog;
    Eina_List       *instances;
-   E_Menu          *menu;
    Ecore_Exe           *batget_exe;
    Ecore_Event_Handler *batget_data_handler;
    Ecore_Event_Handler *batget_del_handler;
@@ -40,21 +48,16 @@ struct _Config
    int                  time_full;
    int                  have_battery;
    int                  have_power;
-   int                  have_subsystem;
+#ifdef HAVE_ENOTIFY
+   int              desktop_notifications;
+#endif
 #ifdef HAVE_EEZE
    Eeze_Udev_Watch     *acwatch;
    Eeze_Udev_Watch     *batwatch;
+#endif
+#if defined HAVE_EEZE || defined __OpenBSD__
    Eina_Bool            fuzzy;
    int                  fuzzcount;
-#else
-   struct {
-      // FIXME: on bat_conf del dbus_pending_call_cancel(dbus.have);
-      //        then set dbus.have to NULL
-      DBusPendingCall       *have;
-      // FIXME: on bat_conf del e_dbus_signal_handler_del() these
-      E_DBus_Signal_Handler *dev_add;
-      E_DBus_Signal_Handler *dev_del;
-   } dbus;
 #endif
 };
 
@@ -64,15 +67,12 @@ typedef struct _Ac_Adapter Ac_Adapter;
 struct _Battery
 {
    const char *udi;
-#ifdef HAVE_EEZE
+#if defined HAVE_EEZE || defined __OpenBSD__
    Ecore_Poller *poll;
-#else
-   E_DBus_Signal_Handler *prop_change;
-   Eina_Bool can_charge:1;
 #endif
    Eina_Bool present:1;
    Eina_Bool charging:1;
-#ifdef HAVE_EEZE
+#if defined HAVE_EEZE || defined __OpenBSD__
    double last_update;
    double percent;
    double current_charge;
@@ -96,16 +96,21 @@ struct _Battery
    const char *model;
    const char *vendor;
    Eina_Bool got_prop:1;
+   Eldbus_Proxy *proxy;
+#ifdef __OpenBSD__
+   int * mib;
+#endif
 };
 
 struct _Ac_Adapter
 {
    const char *udi;
-#ifndef HAVE_EEZE
-   E_DBus_Signal_Handler *prop_change;
-#endif
    Eina_Bool present:1;
    const char *product;
+   Eldbus_Proxy *proxy;
+#ifdef __OpenBSD__
+   int * mib;
+#endif
 };
 
 Battery *_battery_battery_find(const char *udi);
@@ -113,14 +118,19 @@ Ac_Adapter *_battery_ac_adapter_find(const char *udi);
 void _battery_device_update(void);
 #ifdef HAVE_EEZE
 /* in e_mod_udev.c */
-void _battery_udev_start(void);
+int  _battery_udev_start(void);
 void _battery_udev_stop(void);
 /* end e_mod_udev.c */
-#else
+#elif !defined __OpenBSD__
 /* in e_mod_dbus.c */
-void _battery_dbus_start(void);
-void _battery_dbus_stop(void);
+int _battery_upower_start(void);
+void _battery_upower_stop(void);
 /* end e_mod_dbus.c */
+#else
+/* in e_mod_openbsd.c */
+int _battery_openbsd_start(void);
+void _battery_openbsd_stop(void);
+/* end e_mod_openbsd.c */
 #endif
 
 EAPI extern E_Module_Api e_modapi;
@@ -134,4 +144,16 @@ E_Config_Dialog *e_int_config_battery_module(E_Container *con, const char *param
 void _battery_config_updated(void);
 extern Config *battery_config;
 
+/**
+ * @addtogroup Optional_Gadgets
+ * @{
+ *
+ * @defgroup Module_Battery Battery
+ *
+ * Shows battery level and current status, may do actions given some
+ * thresholds.
+ *
+ * @}
+ */
+
 #endif
