@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifndef E_MOD_MAIN_H
 #define E_MOD_MAIN_H
 
@@ -15,7 +12,6 @@ struct _Config
    E_Module        *module;
    E_Config_Dialog *config_dialog;
    Eina_List       *instances;
-   E_Menu          *menu;
    Eina_List       *handlers;
 };
 
@@ -25,6 +21,9 @@ struct _Config_Item
    const char *dir;
    int show_label;
    int eap_label;
+   int lock_move;
+   int dont_add_nonorder;
+   unsigned char dont_track_launch;
 };
 
 EAPI extern E_Module_Api e_modapi;
@@ -37,4 +36,15 @@ void _ibar_config_update(Config_Item *ci);
 void _config_ibar_module(Config_Item *ci);
 extern Config *ibar_config;
 
+/**
+ * @addtogroup Optional_Gadgets
+ * @{
+ *
+ * @defgroup Module_IBar IBar (Icon Launch Bar)
+ *
+ * Launches applications from an icon bar, usually placed on shelves.
+ *
+ * @}
+ */
+
 #endif
