@@ -254,9 +254,9 @@ _il_home_desks_populate(void)
 
              if (sm->type != EFREET_MENU_ENTRY_DESKTOP) continue;
              if (!(desktop = sm->desktop)) continue;
-	     if ((settings) && (sys) && 
-		 (eina_list_data_find(settings, desktop)) && 
-		 (eina_list_data_find(sys, desktop))) continue;
+             if ((settings) && (sys) && 
+                 (eina_list_data_find(settings, desktop)) && 
+                 (eina_list_data_find(sys, desktop))) continue;
              if ((kbd) && (eina_list_data_find(kbd, desktop))) 
                continue;
              efreet_desktop_ref(desktop);
@@ -285,7 +285,7 @@ _il_home_desktop_run(Il_Home_Win *hwin, Efreet_Desktop *desktop)
    Il_Home_Exec *exec;
    Eina_List *l;
    E_Border *bd;
-   char buff[PATH_MAX];
+   char buff[4096];
 
    if ((!hwin) || (!desktop) || (!desktop->exec)) return;
    EINA_LIST_FOREACH(exes, l, exec) 
@@ -356,7 +356,7 @@ _il_home_desktop_find_border(E_Zone *zone, Efreet_Desktop *desktop)
         if (e_exec_startup_id_pid_find(bd->client.netwm.pid, 
                                        bd->client.netwm.startup_id) == desktop) 
           {
-             if (exe) free(exe);
+             free(exe);
              return bd;
           }
         if (exe) 
@@ -381,7 +381,7 @@ _il_home_desktop_find_border(E_Zone *zone, Efreet_Desktop *desktop)
                }
           }
      }
-   if (exe) free(exe);
+   free(exe);
    return NULL;
 }
 
@@ -423,6 +423,7 @@ _il_home_win_new(E_Zone *zone)
 
    hwin->o_bg = edje_object_add(evas);
    edje_object_file_set(hwin->o_bg, bgfile, "e/desktop/background");
+   eina_stringshare_del(bgfile);
    evas_object_move(hwin->o_bg, 0, 0);
    evas_object_show(hwin->o_bg);
 
@@ -593,7 +594,7 @@ _il_home_cb_border_add(void *data __UNUSED__, int type __UNUSED__, void *event)
              exe->border->x = exe->zone->x;
              exe->border->y = exe->zone->y;
              exe->border->changes.pos = 1;
-             exe->border->changed = 1;
+             BD_CHANGED(exe->border);
           }
         if (exe->handle) 
           {
@@ -618,7 +619,6 @@ _il_home_cb_border_del(void *data __UNUSED__, int type __UNUSED__, void *event)
      {
         if (exe->border == ev->border) 
           {
-             if (exe->exec) ecore_exe_free(exe->exec);
              exe->exec = NULL;
              if (exe->handle) e_busycover_pop(exe->cover, exe->handle);
              exe->handle = NULL;
@@ -650,7 +650,7 @@ _il_home_cb_exe_del(void *data __UNUSED__, int type __UNUSED__, void *event)
                }
              exes = eina_list_remove_list(exes, l);
              if (exe->timeout) ecore_timer_del(exe->timeout);
-	     if (exe->desktop) efreet_desktop_free(exe->desktop);
+             if (exe->desktop) efreet_desktop_free(exe->desktop);
              E_FREE(exe);
              break;
           }
@@ -740,17 +740,18 @@ _il_home_cb_bg_change(void *data __UNUSED__, int type, void *event __UNUSED__)
 
    EINA_LIST_FOREACH(hwins, l, hwin) 
      {
-	E_Zone *zone;
-	E_Desk *desk;
-	const char *bgfile;
+        E_Zone *zone;
+        E_Desk *desk;
+        const char *bgfile;
 
-	zone = hwin->zone;
-	desk = e_desk_current_get(zone);
-	if (desk)
-	  bgfile = e_bg_file_get(zone->container->num, zone->num, desk->x, desk->y);
-	else
-	  bgfile = e_bg_file_get(zone->container->num, zone->num, -1, -1);
-	edje_object_file_set(hwin->o_bg, bgfile, "e/desktop/background");
+        zone = hwin->zone;
+        desk = e_desk_current_get(zone);
+        if (desk)
+          bgfile = e_bg_file_get(zone->container->num, zone->num, desk->x, desk->y);
+        else
+          bgfile = e_bg_file_get(zone->container->num, zone->num, -1, -1);
+        edje_object_file_set(hwin->o_bg, bgfile, "e/desktop/background");
+        eina_stringshare_del(bgfile);
      }
 
    return ECORE_CALLBACK_PASS_ON;
